@@ -7,14 +7,8 @@ import signer_pdf.sign_generator as sign_generator
 
 
 def sign(name, date, a_hash, position, in_file):
-
-
-
-    original = PyPDF2.PdfFileReader(in_file)
+    original = PyPDF2.PdfFileReader(in_file, strict=False)
     first_page = original.getPage(0)
-    page_media = first_page.mediaBox
-
-
 
     pdf_with_signed_page = PyPDF2.PdfFileWriter()
     pdf_with_signed_page.addPage(first_page)
@@ -24,15 +18,7 @@ def sign(name, date, a_hash, position, in_file):
 
     images = convert_from_bytes(pdf_with_signed_page_bytes.read())
 
-
-    # pdf_with_signed_page_image = Image(file=pdf_with_signed_page_bytes)
-    # pdf_with_signed_page_image.convert("png")
-    # pdf_with_signed_page_image_bytes = io.BytesIO()
-    # pdf_with_signed_page_image.save(file=pdf_with_signed_page_image_bytes)
-
     signed_page_bytes = sign_generator.convert(name, date, a_hash, position, images[0])
-
-
     signed_page = PyPDF2.PdfFileReader(signed_page_bytes).getPage(0)
 
     media_3 = float(first_page['/MediaBox'][3])
@@ -41,9 +27,7 @@ def sign(name, date, a_hash, position, in_file):
     else:
         signed_page.scaleTo(float(first_page['/MediaBox'][2]), media_3 if media_3 > 0 else float(first_page['/MediaBox'][1]))
 
-
     output_signed_pdf = PyPDF2.PdfFileWriter()
-
     for i in range(original.getNumPages()):
         if i == 0:
             output_signed_pdf.addPage(signed_page)
